"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var useClient_1 = require("./useClient");
var EMPTY_ARRAY = [];
/**
 * Get an array of errors thrown by mutations and a function to dismiss
 * a given error.
 *
 * N.B. ignores errors thrown before you call useMutationErrors
 */
function useMutationErrors() {
    var client = useClient_1.default();
    var _a = React.useState(EMPTY_ARRAY), errors = _a[0], setErrors = _a[1];
    React.useEffect(function () {
        var subscription = client.subscribeToMutationErrors(function (error) {
            setErrors(function (errors) { return errors.concat([error]); });
        });
        return function () {
            subscription.unsubscribe();
        };
    }, [client]);
    return [
        errors,
        function (err) { return setErrors(function (errors) { return errors.filter(function (e) { return e !== err; }); }); },
    ];
}
exports.default = useMutationErrors;
//# sourceMappingURL=useMutationErrors.js.map