import * as React from 'react';
import ErrorResult from 'bicycle/types/ErrorResult';
import { BaseRootQuery } from 'bicycle/typed-helpers/query';
import DeepPartial from './helpers/DeepPartial';
import DeepPartialUnion from './helpers/DeepPartialUnion';
import Query from 'bicycle/types/Query';
export interface SuccessResponse<TResult> {
    loaded: true;
    loading: false;
    errored: false;
    result: TResult;
}
export interface ErrorResponse<TResult> {
    loaded: false;
    loading: false;
    errored: true;
    result: DeepPartialUnion<TResult, ErrorResult>;
    errors: ReadonlyArray<string>;
    errorDetails: ReadonlyArray<ErrorResult>;
    render: () => React.ReactElement<unknown>;
}
export interface LoadingResponse<TResult> {
    loaded: false;
    loading: true;
    errored: false;
    result: DeepPartial<TResult>;
    loadingDuration: number;
    render: () => React.ReactElement<unknown>;
}
export declare type Response<TResult> = SuccessResponse<TResult> | ErrorResponse<TResult> | LoadingResponse<TResult>;
/**
 * Subscribe to the results of a bicycle query
 *
 * @param query The query to subscribe to
 */
export default function useQuery<QueryResult>(query: Query | BaseRootQuery<QueryResult>): Response<QueryResult>;
